package com.localmatters.collector.queue.consumer;

import com.localmatters.collector.queue.CollectorQueueException;

/**
 * The collector consumer service interface.
 *
 * @author Daniel Cavalcanti
 */
public interface ConsumerService {
    
    /**
     * Retrieves a message from the queue. If there are no messages in the
     * queue, blocks until a message becomes available.
     * 
     * @return The message.
     * @throws com.localmatters.collector.queue.consumer.CollectorQueueException If there is an error in the collector queue.
     */
    public String retrieve()
    throws CollectorQueueException;
    
    /**
     * Retrieves a message from the queue. If there are no messages in the
     * queue, blocks until a message becomes available, or the timeout expires.
     *
     * @param timeout The message timeout period in milliseconds.
     * @return The message if one was available; otherwise, null.
     * @throws com.localmatters.collector.queue.consumer.CollectorQueueException If there is an error in the collector queue.
     */
    public String retrieveTimed(long timeout)
    throws CollectorQueueException;
    
    /**
     * Retrieves a message from the queue. If there are no messages in the
     * queue, the call does not block but returns a null immediately.
     *
     * @return The message if one was available; otherwise, null.
     * @throws com.localmatters.collector.queue.consumer.CollectorQueueException If there is an error in the collector queue.
     */
    public String retrieveImmediate()
    throws CollectorQueueException;
    
}
